summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorKay Sievers <kay@vrfy.org>2013-02-19 20:38:19 +0100
committerKay Sievers <kay@vrfy.org>2013-02-19 20:38:48 +0100
commitad67c71f155a078d9223ea02d6e44161f00227d8 (patch)
treeaad109db660d07899e5e71fd66ddb9e821a1bb12
parent90690f92637d75aa3e9983a3b2bb1231053848b0 (diff)
setup: man - update
-rw-r--r--.gitignore1
-rw-r--r--src/setup/gummiboot.xml32
-rw-r--r--src/setup/setup.c4
3 files changed, 21 insertions, 16 deletions
diff --git a/.gitignore b/.gitignore
index 9075c11..f08fe43 100644
--- a/.gitignore
+++ b/.gitignore
@@ -1,6 +1,7 @@
*.o
*.so
/gummiboot
+/gummiboot.1
/gummiboot.so
/gummibootia32.efi
/gummibootx64.efi
diff --git a/src/setup/gummiboot.xml b/src/setup/gummiboot.xml
index 017e567..699bff5 100644
--- a/src/setup/gummiboot.xml
+++ b/src/setup/gummiboot.xml
@@ -63,26 +63,30 @@
<title>Description</title>
<para><command>gummibot</command> checks, updates,
- installs or removes the boot manager from the current
+ installs or removes the boot loader from the current
system.</para>
- <para><command>gummiboot status</command> checks and
- prints the currently installed version of the boot
- manager.</para>
+ <para><command>gummiboot status</command> checks and prints the
+ currently installed versions of the boot loader binaries and the
+ all current EFI boot variables.</para>
<para><command>gummiboot update</command> updates all installed
versions of gummiboot, if the current version is newer than the
- version installed in the EFI system partition, and create a
- gummiboot entry in the EFI boot variables if there is no entry
- already.</para>
-
- <para><command>gummiboot install</command>
- installs gummiboot into the EFI system partition, and create
- an active entry in the EFI boot varaibles.</para>
+ version installed in the EFI system partition. This also includes
+ the EFI default/fallback loader at /EFI/BOOT/BOOT*.EFI. An
+ gummiboot entry in the EFI boot variables is created, if there
+ is no current entry. A created entry will be added to the end of
+ the boot order list.</para>
+
+ <para><command>gummiboot install</command> installs gummiboot into
+ the EFI system partition. A copy of gummiboot will be stored as
+ the EFI default/fallback loader at /EFI/BOOT/BOOT*.EFI. An gummiboot
+ entry in the EFI boot variables is created and added to the top
+ of the boot order list.</para>
<para><command>gummiboot remove</command> removes all installed
- versions of gummiboot from the EFI system partition, and remove
- all gummiboot entries from the EFI boot variables.</para>
+ versions of gummiboot from the EFI system partition, and removes
+ gummiboot from the EFI boot variables.</para>
<para>If no command is passed <command>status</command> is
implied.</para>
@@ -110,7 +114,7 @@
<varlistentry>
<term><option>--no-variables</option></term>
<listitem><para>Do not touch the EFI boot
- variables in the firmware.</para></listitem>
+ variables.</para></listitem>
</varlistentry>
</variablelist>
</refsect1>
diff --git a/src/setup/setup.c b/src/setup/setup.c
index fceb685..9ba58f8 100644
--- a/src/setup/setup.c
+++ b/src/setup/setup.c
@@ -397,7 +397,7 @@ static int status_binaries(const char *esp_path) {
r = enumerate_binaries(esp_path, "EFI/BOOT", "BOOT");
if (r == 0)
- fprintf(stderr, "\tNo fallback boot loader installed in ESP.\n");
+ fprintf(stderr, "\tNo default/fallback boot loader installed in ESP.\n");
else if (r < 0)
return r;
@@ -765,7 +765,7 @@ static int copy_one_file(const char *esp_path, const char *name, bool force) {
if (strncmp(name, "gummiboot", 9) == 0) {
int k;
/* Create the fallback boot loader name (specified for removable devices) */
if (asprintf(&v, "%s/EFI/BOOT/%s", esp_path, name + 5) < 0) {
fprintf(stderr, "Out of memory.\n");
r = -ENOMEM;
@@ -765,7 +765,7 @@ static int copy_one_file(const char *esp_path, const char *name, bool force) {
if (strncmp(name, "gummiboot", 9) == 0) {
int k;
- /* Create the fallback boot loader name (specified for removable devices) */
+ /* Create the EFI default boot loader name (specified for removable devices) */
if (asprintf(&v, "%s/EFI/BOOT/%s", esp_path, name + 5) < 0) {
fprintf(stderr, "Out of memory.\n");